@@ -1579,7 +1579,8 @@ that day if it failed."
 	    "\\(<img[\t\n ]+[^>]+>\\(?:[\t\n ]*</[^>]+>\\)*\\)[\t\n ]*"
 	    nil t)
       (when (or (save-match-data
-		  (looking-at "\\(?:<[^\t\n >]+>[\t\n ]*\\)*<img[\t\n ]"))
+		  (looking-at "\\(?:<[^\t\n >]+>[\t\n ]*\\)*<img[\t\n ]\
+\\|<small>[^<]+</small>"))
 		(not (eq (char-after) ?<)))
 	(replace-match "\\1<br>\n")))
     ;; Add line breaks before images that follow captions.
@@ -1601,6 +1602,12 @@ that day if it failed."
 		    (shimbun-end-of-tag "div" t)))
 	(delete-region start (match-end 0))
 	(insert "\n")))
+    ;; Remove blogs link.
+    (goto-char (point-min))
+    (while (re-search-forward "[\t\n ]*\\(?:<[^/][^>]+>[\t\n ]*\\)+\
+$B$3$N5-;v$rMxMQ$7$?%V%m%00lMw(B\\(?:[\t\n ]*<[!/][^>]+>\\)+[\t\n ]*"
+			      nil t)
+      (delete-region (match-beginning 0) (match-end 0)))
     ;; Remove any other useless things.
     (goto-char (point-min))
     (while (re-search-forward "[\t\n ]*\
