@@ -1,6 +1,6 @@
 ;;; sb-kantei.el --- shimbun backend for kantei mail magazine backnumber -*- coding: iso-2022-7bit; -*-
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
 ;; Yuuichi Teranishi <teranisi@gohome.org>
 
 ;; Author: Yuuichi Teranishi <teranisi@gohome.org>
@@ -35,8 +35,10 @@
 
 (defvar shimbun-kantei-groups '("m-magazine-en"
 				"m-magazine-ja"
-				"m-magazine-cn"
-				"m-magazine-kr"
+				"m-magazine-cn.hatoyama"
+				"m-magazine-kr.hatoyama"
+				"m-magazine-en.hatoyama"
+				"m-magazine-ja.hatoyama"
 				"m-magazine-en.aso"
 				"m-magazine-ja.aso"
 				"m-magazine-en.fukuda"
@@ -45,18 +47,26 @@
 				"m-magazine-ja.abe"
 				"m-magazine-en.koizumi"
 				"m-magazine-ja.koizumi"
-				"m-magazine")
+				;; Backward compatibility.
+				"m-magazine"
+				"m-magazine-cn"
+				"m-magazine-kr")
   "List of the groups subscribing to the email magazin of Japan's Cabinet.
-Note that the `m-magazine-ja.koizumi' is the same as `m-magazine' which
-is for the backward compatibility.")
+Note that the `m-magazine-ja.koizumi' is the same as `m-magazine'
+which is for the backward compatibility; so are `m-magazine-cn' and
+`m-magazine-kr' for those of Hatoyama.")
 
 (defvar shimbun-kantei-x-face-alist
   ;; Don't change the order of the faces.  See the method function that
   ;; is applied to `shimbun-make-contents'.
-  '(("default" . "X-Face: Bhu:2dJ9#&[pX@hMRh=$pF|<M}p@,Fe{2SAS)tupW4j\
-k^RavhwxRqDm>O>-,*d\"V+@u\"gB5\n ]}Yxh$n#S1BM<uz\\n|sXtBh\"1TH|g@:n,M\
-4A7Cr8,MO$L-KmDmX&~)G+W:6gN0?c:5&o=JAJF6b7%_\n A{A`1-=;*q;RtW>o,8|XYs\
-IrL4grl\\|6JV<A.,@%,RI\"v^EIY_[<>6fq3!B`28KP2,M/.Tsh")
+  '(("default" . "X-Face: %irfZ0Z2=ufp].[Z8oJn?QOR6(SRBRW6:IDVMSO25/v\
+SE]crv)dR/UBKa,6}+f9+2X$<v(+\n g&&t<oIo8|TUGOzHIQ!LzA@y7g)@)Fv,3Q'KXs\
+n:a\"{Y(S#41h+0B\"w}n?QdR}5-@[q5exee!SQ'Fj\n HD@V`O1~7H$b%)F`_9{|rqKa\
+F4(\\M2EW?")
+    ("\\.hatoyama\\'" . "X-Face: Bhu:2dJ9#&[pX@hMRh=$pF|<M}p@,Fe{2SAS\
+)tupW4jk^RavhwxRqDm>O>-,*d\"V+@u\"gB5\n ]}Yxh$n#S1BM<uz\\n|sXtBh\"1TH\
+|g@:n,M4A7Cr8,MO$L-KmDmX&~)G+W:6gN0?c:5&o=JAJF6b7%_\n A{A`1-=;*q;RtW>\
+o,8|XYsIrL4grl\\|6JV<A.,@%,RI\"v^EIY_[<>6fq3!B`28KP2,M/.Tsh")
     ("\\.aso\\'" . "X-Face: #(b'i|jCr9M1k*o`B1YbD.C*%\\T3~.mUK@q?}o4.\
 TC*~*~fPaHg\\]V+Q2$3wu$=:[<k^Y<s\n X{VB1rZN[(X$(Cej@QV?FaoslWKi,fxp\"\
 m\\<Cb#4vo!!hDZI@9I8gAMMp6>HZ'C/&9e15i*4e>OV4`\n pdAVvpz`w<$QCu9'~:}|\
@@ -81,10 +91,14 @@ REbDs'H9$Iy#yM#*J2c'L},(m8K:8?$vTPC%D}YJ[bV#7xw|{\"DJ:_?`V1m_4^+;7+\n\
     (concat (shimbun-url-internal shimbun)
 	    (cond ((string-equal group "m-magazine-en")
 		   "foreign/m-magazine/backnumber/hatoyama.html")
-		  ((string-equal group "m-magazine-cn")
+		  ((string-equal group "m-magazine-cn.hatoyama")
 		   "foreign/m-magazine/backnumber_ch/hatoyama_index.html")
-		  ((string-equal group "m-magazine-kr")
+		  ((string-equal group "m-magazine-kr.hatoyama")
 		   "foreign/m-magazine/backnumber_ko/hatoyama_index.html")
+		  ((string-equal group "m-magazine-en.hatoyama")
+		   "foreign/m-magazine/backnumber/hatoyama.html")
+		  ((string-equal group "m-magazine-ja.hatoyama")
+		   "jp/m-magazine/backnumber/hatoyama.html")
 		  ((string-equal group "m-magazine-en.aso")
 		   "foreign/m-magazine/backnumber/aso.html")
 		  ((string-equal group "m-magazine-ja.aso")
@@ -101,19 +115,29 @@ REbDs'H9$Iy#yM#*J2c'L},(m8K:8?$vTPC%D}YJ[bV#7xw|{\"DJ:_?`V1m_4^+;7+\n\
 		   "foreign/m-magazine/backnumber/koizumi.html")
 		  ((string-equal group "m-magazine-ja.koizumi")
 		   "jp/m-magazine/backnumber/koizumi.html")
-		  ((string-equal group "m-magazine") ;; Backward compatibility.
+		  ;; Backward compatibility.
+		  ((string-equal group "m-magazine")
 		   "jp/m-magazine/backnumber/koizumi.html")
+		  ((string-equal group "m-magazine-cn")
+		   "foreign/m-magazine/backnumber_ch/hatoyama_index.html")
+		  ((string-equal group "m-magazine-kr")
+		   "foreign/m-magazine/backnumber_ko/hatoyama_index.html")
+		  ;; Default.
 		  (t
 		   "jp/m-magazine/backnumber/")))))
 
 (luna-define-method shimbun-from-address ((shimbun shimbun-kantei))
   (let ((group (shimbun-current-group-internal shimbun)))
     (cond ((string-equal group "m-magazine-en")
-	   "Yukio Hatoyama")
-	  ((string-equal group "m-magazine-cn")
+	   "Naoto Kan")
+	  ((string-equal group "m-magazine-cn.hatoyama")
 	   "$Ap/$B;3M3$A<M$BIW(B")
-	  ((string-equal group "m-magazine-kr")
+	  ((string-equal group "m-magazine-kr.hatoyama")
 	   "$(CGOEd>_86(B $(C@/E0?@(B")
+	  ((string-equal group "m-magazine-en.hatoyama")
+	   "Yukio Hatoyama")
+	  ((string-equal group "m-magazine-ja.hatoyama")
+	   "$BH7;3M35*IW(B")
 	  ((string-equal group "m-magazine-en.aso")
 	   "Taro Aso")
 	  ((string-equal group "m-magazine-ja.aso")
@@ -133,7 +157,7 @@ REbDs'H9$Iy#yM#*J2c'L},(m8K:8?$vTPC%D}YJ[bV#7xw|{\"DJ:_?`V1m_4^+;7+\n\
 	  ((string-equal group "m-magazine") ;; Backward compatibility.
 	   "$B>.@t=c0lO:(B")
 	  (t
-	   "$BH7;3M35*IW(B"))))
+	   "$B?{D>?M(B"))))
 
 (luna-define-method shimbun-get-headers ((shimbun shimbun-kantei)
 					 &optional range)
@@ -373,7 +397,7 @@ go[\t\n ]+to[\t\n ]+top[\t\n ]+of[\t\n ]+the[\t\n ]+page[\t\n ]*</a>\
 
 (luna-define-method shimbun-make-contents :around ((shimbun shimbun-kantei)
 						   header)
-  (if (string-match "\\`m-magazine-\\(?:en\\|ja\\)\\'"
+  (if (string-match "\\`m-magazine-\\(?:cn\\|en\\|ja\\|kr\\)\\'"
 		    (shimbun-current-group-internal shimbun))
       ;; Choose a face according to the author.
       (let ((shimbun-x-face-database-function
@@ -381,18 +405,23 @@ go[\t\n ]+to[\t\n ]+top[\t\n ]+of[\t\n ]+the[\t\n ]+page[\t\n ]*</a>\
 		 (let ((from (shimbun-header-from header t)))
 		   `(lambda (ignore)
 		      ,(cdr (nth
-			     (cond ((member from '("Taro Aso"
-						   "$BKc@8B@O:(B"))
+			     (cond ((member from '("Yukio Hatoyama"
+						   "$BH7;3M35*IW(B"
+						   "$Ap/$B;3M3$A<M$BIW(B"
+						   "$(CGOEd>_86(B $(C@/E0?@(B"))
 				    1)
+				   ((member from '("Taro Aso"
+						   "$BKc@8B@O:(B"))
+				    2)
 				   ((member from '("Yasuo Fukuda"
 						   "$BJ!ED9/IW(B"))
-				    2)
+				    3)
 				   ((member from '("Shinzo Abe"
 						   "$B0BG\?8;0(B"))
-				    3)
+				    4)
 				   ((member from '("Junichiro Koizumi"
 						   "$B>.@t=c0lO:(B"))
-				    4)
+				    5)
 				   (t
 				    0))
 			     shimbun-kantei-x-face-alist)))))))
