@@ -1,6 +1,6 @@
 ;;; sb-mainichi.el --- shimbun backend for Mainichi jp -*- coding: iso-2022-7bit; -*-
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
 ;; Koichiro Ohba <koichiro@meadowy.org>
 
 ;; Author: Koichiro Ohba <koichiro@meadowy.org>
@@ -33,9 +33,10 @@
 ;;; Code:
 
 (require 'sb-rss)
+(require 'sb-multi)
 
 (luna-define-class shimbun-mainichi (shimbun-japanese-newspaper
-				     shimbun-rss) ())
+				     shimbun-multi shimbun-rss) ())
 
 (defvar shimbun-mainichi-url "http://mainichi.jp/")
 
@@ -79,7 +80,9 @@
     ("opinion.kaisetsu" "$BEZMK2r@b(B"
      "http://mainichi.jp/select/opinion/kaisetsu/")
     ("opinion.newsup" "$B%K%e!<%9#U#P(B"
-     "http://mainichi.jp/select/opinion/newsup/")))
+     "http://mainichi.jp/select/opinion/newsup/")
+    ("entertainment.art" "$B7]=Q!&J82=(B"
+     "http://mainichi.jp/enta/art/archive/")))
 
 (defvar shimbun-mainichi-x-face-alist
   '(("default" . "\
@@ -121,10 +124,24 @@ Face: iVBORw0KGgoAAAANSUhEUgAAABwAAAAcBAMAAACAI8KnAAAABGdBTUEAALGPC/xhBQAAABh
 		      (shimbun-current-group-name shimbun) ")"))
 	headers)
     (if (string-match "\\.rss\\'" (shimbun-index-url shimbun))
-	(dolist (header (setq headers (luna-call-next-method)) headers)
-	  (shimbun-header-set-from header from))
+	(progn
+	  (shimbun-strip-cr)
+	  (goto-char (point-min))
+	  (while (and (search-forward "<title><![CDATA[AD:" nil t)
+		      (re-search-backward "<item[\t\n ]*" nil t)
+		      (shimbun-end-of-tag "item" t))
+	    (replace-match "\n"))
+	  (dolist (header (setq headers (luna-call-next-method)) headers)
+	    (shimbun-header-set-from header from)))
       (shimbun-mainichi-get-headers shimbun range from))))
 
+(luna-define-method shimbun-rss-build-message-id :around ((shimbun
+							   shimbun-mainichi)
+							  url &optional date)
+  ;; Don't strip string following "?" or "#" in url.  See sb-rss.el.
+  (concat "<" (md5 url) "%" (shimbun-current-group shimbun)
+	  "@" (shimbun-server shimbun) ".shimbun.namazu.org>"))
+
 (defun shimbun-mainichi-get-headers (shimbun range from)
   "Get headers for non-RSS groups."
   (let ((rgrp (mapconcat 'identity
@@ -208,6 +225,21 @@ Face: iVBORw0KGgoAAAANSUhEUgAAABwAAAAcBAMAAACAI8KnAAAABGdBTUEAALGPC/xhBQAAABh
 	  (throw 'stop nil))))
     headers))
 
+(luna-define-method shimbun-multi-next-url ((shimbun shimbun-mainichi)
+					    header url)
+  (shimbun-mainichi-multi-next-url shimbun header url))
+
+(defun shimbun-mainichi-multi-next-url (shimbun header url)
+  (goto-char (point-min))
+  (when (and (re-search-forward "\
+<div[\t\n ]\\(?:[^\t\n >]+[\t\n ]+\\)*class=\"PageBtn\""
+				nil t)
+	     (shimbun-end-of-tag "div")
+	     (re-search-backward "\
+<a[\t\n ]+href=\"\\([^\"]+\\)\"[^>]*>[\t\n ]*$B<!$X(B[^<]*</a>"
+				 (match-beginning 0) t))
+    (shimbun-expand-url (match-string 1) url)))
+
 (luna-define-method shimbun-clear-contents :around ((shimbun shimbun-mainichi)
 						    header)
   (shimbun-mainichi-clear-contents shimbun header))
@@ -280,6 +312,23 @@ Face: iVBORw0KGgoAAAANSUhEUgAAABwAAAAcBAMAAACAI8KnAAAABGdBTUEAALGPC/xhBQAAABh
 &nbsp;$B$^$?$O<hF@$K<:GT$7$?$N$+$b$7$l$^$;$s!#(B)</body></html>\n")
       nil)))
 
+(luna-define-method shimbun-multi-clear-contents :around ((shimbun
+							   shimbun-mainichi)
+							  header
+							  has-previous-page
+							  has-next-page)
+  (shimbun-mainichi-multi-clear-contents shimbun header
+					 has-previous-page has-next-page))
+
+(defun shimbun-mainichi-multi-clear-contents (shimbun header
+						      has-previous-page
+						      has-next-page)
+  (when (luna-call-next-method)
+    (when has-previous-page
+      (goto-char (point-min))
+      (insert "&#012;\n"))
+    t))
+
 (provide 'sb-mainichi)
 
 ;;; sb-mainichi.el ends here
