@@ -1,6 +1,6 @@
 ;;; shimbun.el --- interfacing with web newspapers -*- coding: iso-2022-7bit; -*-
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
 ;; Yuuichi Teranishi <teranisi@gohome.org>
 
 ;; Author: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
@@ -592,16 +592,33 @@ Generated article have a multipart/related content-type."
   "Return MIME charset of ENTITY.")
 (luna-define-method shimbun-text-entity-charset ((entity shimbun-text-entity)
 						 &optional begin end)
-  (or (shimbun-text-entity-charset-internal entity)
-      (shimbun-text-entity-set-charset-internal
-       entity
-       (upcase
-	(symbol-name
-	 (if (and begin end)
-	     (detect-mime-charset-region begin end)
-	   (with-temp-buffer
-	     (insert (shimbun-entity-data-internal entity))
-	     (detect-mime-charset-region (point-min) (point-max)))))))))
+  (let (cur tmp)
+    (unless (and begin end)
+      (setq cur (current-buffer))
+      (set-buffer (generate-new-buffer " *temp*"))
+      (insert (shimbun-entity-data-internal entity))
+      (setq begin (point-min)
+	    end (point-max)
+	    tmp (current-buffer)))
+    (prog1
+	;; Prefer meta charset.
+	(or (let ((charset (progn
+			     (goto-char begin)
+			     (and (re-search-forward "\
+<meta\\s-+http-equiv=[\"']?content-type[\"']?\\s-+content=[\"']\
+text/\\sw+\\(?:\;\\s-*charset=\\(.+\\)\\)?[\"'][^>]*>" end t)
+				  (match-string 1)))))
+	      (when (and charset
+			 (w3m-find-coding-system (intern (downcase charset))))
+		(shimbun-text-entity-set-charset-internal entity
+							  (upcase charset))))
+	    (shimbun-text-entity-charset-internal entity)
+	    (shimbun-text-entity-set-charset-internal
+	     entity (upcase (symbol-name
+			     (detect-mime-charset-region begin end)))))
+      (when cur
+	(set-buffer cur)
+	(kill-buffer tmp)))))
 
 (luna-define-method shimbun-entity-type ((entity shimbun-text-entity))
   (concat (shimbun-entity-type-internal entity)
@@ -684,7 +701,9 @@ image parts, and returns an alist of URLs and image entities."
 		      (substring url 0 (match-beginning 0))
 		    url))
 		 base-url))
-      (unless (setq img (assoc url images))
+      (unless (or (setq img (assoc url images))
+		  (and w3m-ignored-image-url-regexp
+		       (string-match w3m-ignored-image-url-regexp url)))
 	(with-temp-buffer
 	  (set-buffer-multibyte nil)
 	  (setq case-fold-search nil
@@ -760,13 +779,14 @@ you want to use no database."
   (let ((from (shimbun-header-from header))
 	(refs (shimbun-header-references header))
 	(reply-to (shimbun-reply-to shimbun))
-	x-face
-	;; Make sure the temp buffer's multibyteness is true.  It is
-	;; needed to make `encode-mime-charset-string' (which is
-	;; employed by `eword-encode-string') encode non-ascii text.
-	(default-enable-multibyte-characters t))
+	x-face)
     (insert
      (with-temp-buffer
+       ;; Make sure the temp buffer's multibyteness is true.  It is
+       ;; needed to make `encode-mime-charset-string' (which is
+       ;; employed by `eword-encode-string') encode non-ascii text.
+       (static-unless (featurep 'xemacs)
+	 (set-buffer-multibyte t))
        (insert "Subject: " (or (eword-encode-string
 				(shimbun-header-subject header t))
 			       "(none)")
@@ -1259,16 +1279,17 @@ that the content type is text/html, otherwise text/plain."
 (defun shimbun-mime-encode-string (string)
   (condition-case nil
       (save-match-data
-	;; Make sure the temp buffer's multibyteness is true.  It is
-	;; needed to make `encode-mime-charset-string' (which is
-	;; employed by `eword-encode-string') encode non-ascii text.
-	(let ((default-enable-multibyte-characters t))
-	  (with-temp-buffer
-	    (mapconcat
-	     #'identity
-	     (split-string (or (eword-encode-string
-				(shimbun-decode-entities-string string)) ""))
-	     " "))))
+	(with-temp-buffer
+	  ;; Make sure the temp buffer's multibyteness is true.  It is
+	  ;; needed to make `encode-mime-charset-string' (which is
+	  ;; employed by `eword-encode-string') encode non-ascii text.
+	  (static-unless (featurep 'xemacs)
+	    (set-buffer-multibyte t))
+	  (mapconcat
+	   #'identity
+	   (split-string (or (eword-encode-string
+			      (shimbun-decode-entities-string string)) ""))
+	   " ")))
     (error string)))
 
 (defun shimbun-make-date-string (year month day &optional time timezone)
@@ -1491,9 +1512,10 @@ Use ## to put a single # into the output.  If `shimbun-verbose' is nil,
 it will run silently.  The `shimbun-message-enable-logging' variable
 controls whether this function should preserve a message in the
 *Messages* buffer."
-  (let ((default-enable-multibyte-characters t)
-	specifier)
+  (let (specifier)
     (with-temp-buffer
+      (static-unless (featurep 'xemacs)
+	(set-buffer-multibyte t))
       (insert fmt)
       (goto-char (point-min))
       (while (search-forward "#" nil t)
