@@ -1,6 +1,6 @@
 ;;; w3m-tabmenu.el --- Functions for TAB menu browsing
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2009
 ;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: Hideyuki SHIRAI    <shirai@meadowy.org>,
@@ -110,7 +110,7 @@
 (defvar w3m-tab-menubar-items-sub-coeff 30) ;; 30?
 (defvar w3m-tab-menubar-items-width 50) ;; 50?
 
-(defsubst w3m-tab-menubar-make-items-1 (buffers &optional nomenu)
+(defun w3m-tab-menubar-make-items-1 (buffers &optional nomenu)
   (let ((i 0)
 	(current (current-buffer))
 	(width w3m-tab-menubar-items-width)
