@@ -1,6 +1,6 @@
 ;;; w3m-util.el --- Utility macros and functions for emacs-w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
 ;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
@@ -63,6 +63,7 @@
   (defvar w3m-mode-map)
   (defvar w3m-use-title-buffer-name)
   (defvar w3m-buffer-unseen)
+  (defvar w3m-puny-utf-16be)
   (unless (fboundp 'select-frame-set-input-focus)
     (defalias 'select-frame-set-input-focus 'ignore)))
 
@@ -72,9 +73,9 @@
     (require 'poem)))
 
 ;;; Things should be defined in advance:
-
-(eval-and-compile
-  (autoload 'w3m-fb-frame-parameter "w3m-fb"))
+(eval-when-compile
+  (autoload 'w3m-fb-frame-parameter "w3m-fb")
+  (autoload 'w3m-history-restore-position "w3m-hist" nil t))
 
 ;;; Control structures:
 
@@ -584,12 +585,16 @@ according to `w3m-pop-up-windows' and `w3m-pop-up-frames' (which see)."
 	    (raise-frame frame)
 	    (select-frame frame)
 	    (w3m-static-when (featurep 'xemacs)
-	      (focus-frame frame))))
-      ;; Simply switch to BUFFER in the current frame.
-      (if (w3m-popup-window-p)
-	  (let ((pop-up-windows t))
-	    (pop-to-buffer buffer))
-	(switch-to-buffer buffer)))))
+	      (focus-frame frame)))
+	  (w3m-history-restore-position))
+      (unless (prog1
+		  (eq buffer (current-buffer))
+		;; Simply switch to BUFFER in the current frame.
+		(if (w3m-popup-window-p)
+		    (let ((pop-up-windows t))
+		      (pop-to-buffer buffer))
+		  (switch-to-buffer buffer)))
+	(w3m-history-restore-position)))))
 
 (eval-when-compile
   (when (and (fboundp 'select-frame-set-input-focus)
@@ -1184,8 +1189,7 @@ The value of DEFAULT is inserted into PROMPT."
 
 (defun w3m-unseen-buffer-p (buffer)
   "Return t if buffer unseen."
-  (save-excursion
-    (set-buffer buffer)
+  (with-current-buffer buffer
     w3m-buffer-unseen))
 
 (defun w3m-visited-file-modtime ()
@@ -1205,6 +1209,213 @@ get to be the alias to `visited-file-modtime'."
 	  (t
 	   modtime))))
 
+;;; Punycode RFC 3492:
+
+(defconst w3m-puny-code-regex "xn--\\([-0-9a-zA-z]+\\)")
+(defconst w3m-puny-code-nonascii "[^\000-\177]")
+
+(defconst w3m-puny-base 36)
+(defconst w3m-puny-tmin 1)
+(defconst w3m-puny-tmax 26)
+(defconst w3m-puny-damp 700)
+(defconst w3m-puny-skew 38)
+(defconst w3m-puny-initial-bias 72)
+(defconst w3m-puny-initial-n 128)
+(defconst w3m-puny-delimiter ?-)
+
+(defun w3m-puny-adapt (delta numpoints firsttime)
+  (let ((k 0))
+    (if firsttime
+	(setq delta (/ delta w3m-puny-damp))
+      (setq delta (/ delta 2)))
+    (setq delta (+ delta (/ delta numpoints)))
+    (while (> delta (/ (* (- w3m-puny-base w3m-puny-tmin) w3m-puny-tmax) 2))
+      (setq delta (/ delta (- w3m-puny-base w3m-puny-tmin)))
+      (setq k (+ k w3m-puny-base)))
+    (+ k (/ (* (1+ (- w3m-puny-base w3m-puny-tmin)) delta) (+ delta w3m-puny-skew)))))
+
+(defun w3m-puny-decode-digit (cp)
+  (if (< (- cp 48) 10)
+      (- cp 22)
+    (if (< (- cp 65) 26)
+	(- cp 65)
+      (if (< (- cp 97) 26)
+	  (- cp 97)
+	w3m-puny-base))))
+
+(defun w3m-puny-encode-digit (d)
+  (if (< d 26)
+      (+ d 22 75) ;; a-z
+    (+ d 22))) ;; 0-9
+
+(defun w3m-puny-decode1 (input)
+  (let* ((n w3m-puny-initial-n)
+	 (bias w3m-puny-initial-bias)
+	 (len (length input))
+	 (in 0) (out 0)
+	 (i 0) (b 0)
+	 digit thr oldi w k output ret)
+    (dotimes (j len)
+      (if (= (aref input j) w3m-puny-delimiter) (setq b j)))
+    (dotimes (j b)
+      (setq output (cons (aref input j) output))
+      (setq out (1+ out)))
+    (setq output (nreverse output))
+    (if (> b 0) (setq in (1+ b)) (setq in 0))
+    (while (< in len)
+      (setq oldi i)
+      (setq w 1)
+      (setq k w3m-puny-base)
+      (catch 'loop
+	(while t
+	  (if (>= in len) (error "punycode bad input"))
+	  (setq digit (w3m-puny-decode-digit (aref input in)))
+	  (if (>= digit w3m-puny-base) (error "punycode bad input"))
+	  (setq in (1+ in))
+	  (setq i (+ i (* digit w)))
+	  (if (<= k bias)
+	      (setq thr w3m-puny-tmin)
+	    (if (>= k (+ bias w3m-puny-tmax))
+		(setq thr w3m-puny-tmax)
+	      (setq thr (- k bias))))
+	  (if (< digit thr) (throw 'loop nil))
+	  (setq w (* w (- w3m-puny-base thr)))
+	  (setq k (+ k w3m-puny-base))))
+      (setq out (1+ out))
+      (setq bias (w3m-puny-adapt (- i oldi) out (= oldi 0)))
+      (setq n (+ n (/ i out)))
+      (setq i (% i out))
+      (if (= i 0)
+	  (setq output (cons n (nthcdr i output)))
+	(setcdr (nthcdr (1- i) output) (cons n (nthcdr i output))))
+      (setq i (1+ i)))
+    (setq ret (make-string (* out 2) ?a))
+    (let ((j 0))
+      (dolist (op output)
+	(aset ret j (/ op 256))
+	(setq j (1+ j))
+	(aset ret j (% op 256))
+	(setq j (1+ j))))
+    ret))
+
+(defun w3m-puny-decode (input)
+  (condition-case nil
+      (save-match-data
+	(decode-coding-string
+	 (w3m-puny-decode1 (substring input 4)) ;; xn--
+	 w3m-puny-utf-16be))
+    (error input)))
+
+(defun w3m-puny-decode-url (url)
+  "Decode URL from punycode."
+  (let ((case-fold-search t)
+	prot host after)
+    (when (and w3m-puny-utf-16be
+	       (string-match w3m-puny-code-regex url))
+      (when (string-match "\\`[^:/]+://\\([^/]+\\)" url)
+	(setq prot (substring url 0 (match-beginning 1)))
+	(setq host (substring url (match-beginning 1) (match-end 1)))
+	(setq after (substring url (match-end 0)))
+	(while (string-match w3m-puny-code-regex host)
+	  (setq host
+		(concat (substring host 0 (match-beginning 0))
+			(w3m-puny-decode
+			 (substring host (match-beginning 0) (match-end 0)))
+			(substring host (match-end 0)))))
+	(setq url (concat prot host after))))
+    url))
+
+(defun w3m-puny-encode1 (input)
+  (let* ((len (length input))
+	 (h-len (/ len 2))
+	 (n w3m-puny-initial-n)
+	 (bias w3m-puny-initial-bias)
+	 (delta 0) (out 0)
+	 (output (make-string (* len 4) ?a))
+	 h b m q k thr uni)
+    (dotimes (j len)
+      (setq uni (aref input j))
+      (setq j (1+ j))
+      (setq uni (+ (* uni 256) (aref input j)))
+      (when (< uni 128) ;; basic
+	(aset output out uni)
+	(setq out (1+ out))))
+    (setq h out)
+    (setq b out)
+    (when (> b 0)
+      (aset output out w3m-puny-delimiter)
+      (setq out (1+ out)))
+    (while (< h h-len)
+      (setq m 65536) ;; 17bits
+      (dotimes (j len)
+	(setq uni (aref input j))
+	(setq j (1+ j))
+	(setq uni (+ (* uni 256) (aref input j)))
+	(if (and (>= uni n) (< uni m)) (setq m uni)))
+      (setq delta (+ delta (* (- m n) (1+ h))))
+      (setq n m)
+      (dotimes (j len)
+	(setq uni (aref input j))
+	(setq j (1+ j))
+	(setq uni (+ (* uni 256) (aref input j)))
+	(when (< uni n)
+	  (setq delta (1+ delta))
+	  (if (= delta 0) (error "punycode overflow")))
+	(when (= uni n)
+	  (setq q delta)
+	  (setq k w3m-puny-base)
+	  (catch 'loop
+	    (while t
+	      (if (<= k bias)
+		  (setq thr w3m-puny-tmin)
+		(if (>= k (+ bias w3m-puny-tmax))
+		    (setq thr w3m-puny-tmax)
+		  (setq thr (- k bias))))
+	      (if (< q thr) (throw 'loop nil))
+	      (aset output out (w3m-puny-encode-digit (+ thr (% (- q thr) (- w3m-puny-base thr)))))
+	      (setq out (1+ out))
+	      (setq q (/ (- q thr) (- w3m-puny-base thr)))
+	      (setq k (+ k w3m-puny-base))))
+	  (aset output out (w3m-puny-encode-digit q))
+	  (setq out (1+ out))
+	  (setq bias (w3m-puny-adapt delta (1+ h) (= h b)))
+	  (setq delta 0)
+	  (setq h (1+ h))))
+      (setq delta (1+ delta))
+      (setq n (1+ n)))
+    (substring output 0 out)))
+
+(defun w3m-puny-encode (input)
+  (condition-case nil
+      (concat "xn--" (w3m-puny-encode1
+		      (encode-coding-string input w3m-puny-utf-16be)))
+    (error input)))
+
+(defun w3m-puny-encode-url (url)
+  "Encode URL to punycode."
+  (if (and w3m-puny-utf-16be
+	   (not (w3m-url-local-p url))
+	   (string-match w3m-puny-code-nonascii url))
+      (let (beg end idn)
+	(with-temp-buffer
+	  (insert url)
+	  (goto-char (point-min))
+	  (if (search-forward "://" nil t)
+	      (setq beg (point))
+	    (setq beg (point-min)))
+	  (if (search-forward "/" nil t)
+	      (setq end (1- (point)))
+	    (setq end (point-max)))
+	  (save-restriction
+	    (narrow-to-region beg end)
+	    (goto-char (point-min))
+	    (while (re-search-forward "[^.]?[^.\000-\177][^.]*" nil t)
+	      (setq idn (match-string-no-properties 0))
+	      (delete-region (match-beginning 0) (match-end 0))
+	      (insert (w3m-puny-encode idn))))
+	  (buffer-substring-no-properties (point-min) (point-max))))
+    url))
+
 (provide 'w3m-util)
 
 ;;; w3m-util.el ends here
